//Source file: Activity.java
//Date: June 2006
//Common Data Types for 3GPP TS 29.198-02 V6.5.0

package org.csapi.jr.se;

/**
 * This interface specifies an activity which might be provided by a service.<br>
 * An activity has three states: "idle", "active" and "invalid". <br>
 * The initial state is "idle" and here the listeners should be registered.<br>
 * It performs in the "active" state.<br> 
 * It enters the "invalid" state when it has fulfilled its task or a fatal
 * error occured.<br> 
 * In special cases state transition from "idle" to "invalid" is possible.
 */
public interface Activity extends CsapiInterface {

	/**
	 * This constant value represents the "idle" state.
	 */
	public final static int IDLE_STATE = 0;

	/**
	 * This constant value represents the "active" state.
	 */
	public final static int ACTIVE_STATE = 1;

	/**
	 * This constant value represents the "invalid" state.
	 */
	public final static int INVALID_STATE = 2;

	/**
	 * Gets the state attribute of the Activity object
	 *
	 * @return the state value
	 */
	int getState();

	/**
	 * Add listener to receive notification when the activity object changes state
	 * 
	 * @param activityStateChangeListener object implementing the ActivityStateChangeListener interface
	 */
	public void addActivityStateChangeListener(ActivityStateChangeListener activityStateChangeListener);

	/**
	 * Remove listener for activity state changes
	 * 
	 * @param activityStateChangeListener object implementing the ActivityStateChangeListener interface
	 */
	public void removeActivityStateChangeListener(ActivityStateChangeListener activityStateChangeListener);

} // Activity
