//Source file: Address.java
//Date: June 2006
//Common Data Types for 3GPP TS 29.198-02 V6.5.0

package org.csapi.jr.se;

/**
 * Defines the Sequence of Data Elements that specify an address.
The AddrString defines the actual address information and the structure of the string depends on the Plan. 
NOTE 1: It should be noted that two SIP addresses will be regarded as equivalent by a gateway if they correspond to the same user at the same network address. The textual form of the two addresses need not be the same. For example, sip:enquiries@parlay.org will be deemed to match <sip:Enquiries@1.2.3.4:5060>Enquiries (if parlay.org resolves to 1.2.3.4).
NOTE 2:	P_ADDRESS_PLAN_ANY  is only to be used with TpAddressRange.
 * 
 */
public final class Address implements java.io.Serializable {

    private org.csapi.jr.se.AddressPlan plan;
    private String addrString;
    private String name;
    private org.csapi.jr.se.AddressPresentation presentation;
    private org.csapi.jr.se.AddressScreening screening;
    private String subAddressString;

    /**
     * Creates a new Address instance.
     */
    public Address () {}

    /**
     * Creates a new Address instance.
     * @param _plan   
     * @param _addrString   
     * @param _name   
     * @param _presentation   
     * @param _screening   
     * @param _subAddressString   A possible subAddress associated with the address.
     */
    public Address (org.csapi.jr.se.AddressPlan _plan, String _addrString, String _name, org.csapi.jr.se.AddressPresentation _presentation, org.csapi.jr.se.AddressScreening _screening, String _subAddressString) {

        this.plan = _plan;
        this.addrString = _addrString;
        this.name = _name;
        this.presentation = _presentation;
        this.screening = _screening;
        this.subAddressString = _subAddressString;
    }

    /**
     * This method returns a plan.
     * 
     * @return a org.csapi.jr.se.AddressPlan value
     */
    public org.csapi.jr.se.AddressPlan getPlan() {
        return plan;
    }

    /**
     * This method returns a addrString.
     * 
     * @return a String value
     */
    public String getAddrString() {
        return addrString;
    }

    /**
     * This method returns a name.
     * 
     * @return a String value
     */
    public String getName() {
        return name;
    }

    /**
     * This method returns a presentation.
     * 
     * @return a org.csapi.jr.se.AddressPresentation value
     */
    public org.csapi.jr.se.AddressPresentation getPresentation() {
        return presentation;
    }

    /**
     * This method returns a screening.
     * 
     * @return a org.csapi.jr.se.AddressScreening value
     */
    public org.csapi.jr.se.AddressScreening getScreening() {
        return screening;
    }

    /**
     * This method returns a subAddressString.
     * 
     * @return a String value
     */
    public String getSubAddressString() {
        return subAddressString;
    }


    /**
     * This method sets a plan.
     */ 
    public void setPlan(org.csapi.jr.se.AddressPlan plan) {
        this.plan = plan;
    }

    /**
     * This method sets a addrString.
     */ 
    public void setAddrString(String addrString) {
        this.addrString = addrString;
    }

    /**
     * This method sets a name.
     */ 
    public void setName(String name) {
        this.name = name;
    }

    /**
     * This method sets a presentation.
     */ 
    public void setPresentation(org.csapi.jr.se.AddressPresentation presentation) {
        this.presentation = presentation;
    }

    /**
     * This method sets a screening.
     */ 
    public void setScreening(org.csapi.jr.se.AddressScreening screening) {
        this.screening = screening;
    }

    /**
     * This method sets a subAddressString.
     */ 
    public void setSubAddressString(String subAddressString) {
        this.subAddressString = subAddressString;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof Address)) {
            return false;
        } 
        Address address = (Address) o;
        if ((this.plan != null) && (address.plan != null)) {
            if(!(this.plan.equals(address.plan))) {
                return false;
            }
        }
        if ((this.addrString != null) && (address.addrString != null)) {
            if(!(this.addrString.equals(address.addrString)))  {
                return false;
            }
        }
        if ((this.name != null) && (address.name != null)) {
            if(!(this.name.equals(address.name)))  {
                return false;
            }
        }
        if ((this.presentation != null) && (address.presentation != null)) {
            if(!(this.presentation.equals(address.presentation))) {
                return false;
            }
        }
        if ((this.screening != null) && (address.screening != null)) {
            if(!(this.screening.equals(address.screening))) {
                return false;
            }
        }
        if ((this.subAddressString != null) && (address.subAddressString != null)) {
            if(!(this.subAddressString.equals(address.subAddressString)))  {
                return false;
            }
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // Address

