//Source file: AddressError.java
//Date: June 2006
//Common Data Types for 3GPP TS 29.198-02 V6.5.0

package org.csapi.jr.se;

/**
 * Defines the reasons why an address is invalid. 
 *
 */
public final class AddressError implements java.io.Serializable {

    private int _value;
    private static int _size = 6;
    private static AddressError[] _array = new AddressError[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private AddressError(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Undefined error
     */
    public static final int _ADDRESS_INVALID_UNDEFINED =  0;

    /**
     * Undefined error
     */
    public static final AddressError ADDRESS_INVALID_UNDEFINED = new AddressError(_ADDRESS_INVALID_UNDEFINED);

    /**
     * Mandatory address not present
     */
    public static final int _ADDRESS_INVALID_MISSING =  1;

    /**
     * Mandatory address not present
     */
    public static final AddressError ADDRESS_INVALID_MISSING = new AddressError(_ADDRESS_INVALID_MISSING);

    /**
     * Mandatory address element not present
     */
    public static final int _ADDRESS_INVALID_MISSING_ELEMENT =  2;

    /**
     * Mandatory address element not present
     */
    public static final AddressError ADDRESS_INVALID_MISSING_ELEMENT = new AddressError(_ADDRESS_INVALID_MISSING_ELEMENT);

    /**
     * Address is outside of the valid range
     */
    public static final int _ADDRESS_INVALID_OUT_OF_RANGE =  3;

    /**
     * Address is outside of the valid range
     */
    public static final AddressError ADDRESS_INVALID_OUT_OF_RANGE = new AddressError(_ADDRESS_INVALID_OUT_OF_RANGE);

    /**
     * Address is incomplete
     */
    public static final int _ADDRESS_INVALID_INCOMPLETE =  4;

    /**
     * Address is incomplete
     */
    public static final AddressError ADDRESS_INVALID_INCOMPLETE = new AddressError(_ADDRESS_INVALID_INCOMPLETE);

    /**
     * Address cannot be decoded
     */
    public static final int _ADDRESS_INVALID_CANNOT_DECODE =  5;

    /**
     * Address cannot be decoded
     */
    public static final AddressError ADDRESS_INVALID_CANNOT_DECODE = new AddressError(_ADDRESS_INVALID_CANNOT_DECODE);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved AddressError object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the AddressError object
     */
    public String getValueText() {
        switch (_value) {
            case _ADDRESS_INVALID_UNDEFINED:
                return "ADDRESS_INVALID_UNDEFINED";
            case _ADDRESS_INVALID_MISSING:
                return "ADDRESS_INVALID_MISSING";
            case _ADDRESS_INVALID_MISSING_ELEMENT:
                return "ADDRESS_INVALID_MISSING_ELEMENT";
            case _ADDRESS_INVALID_OUT_OF_RANGE:
                return "ADDRESS_INVALID_OUT_OF_RANGE";
            case _ADDRESS_INVALID_INCOMPLETE:
                return "ADDRESS_INVALID_INCOMPLETE";
            case _ADDRESS_INVALID_CANNOT_DECODE:
                return "ADDRESS_INVALID_CANNOT_DECODE";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 5
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static AddressError getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof AddressError)) {
            return false;
        }
        AddressError addressError = (AddressError) o; 
        if(!(this.getValue() == addressError.getValue())) {
            return false;
        }
        if (this.hashCode() != addressError.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // AddressError

