//Source file: AddressPlan.java
//Date: June 2006
//Common Data Types for 3GPP TS 29.198-02 V6.5.0

package org.csapi.jr.se;

/**
 * Defines the address plan (or numbering plan) used. It is also used to indicate whether an address is actually defined in a TpAddress data element.
For the case where the P_ADDRESS_PLAN_NOT_PRESENT and P_ADDRESS_PLAN_ANY are indicated, the rest of the information in the TpAddress is not valid.
NOTE:	P_ADDRESS_PLAN_MSMAIL is not to be used.
 *
 */
public final class AddressPlan implements java.io.Serializable {

    private int _value;
    private static int _size = 15;
    private static AddressPlan[] _array = new AddressPlan[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private AddressPlan(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * No Address Present
     */
    public static final int _ADDRESS_PLAN_NOT_PRESENT =  0;

    /**
     * No Address Present
     */
    public static final AddressPlan ADDRESS_PLAN_NOT_PRESENT = new AddressPlan(_ADDRESS_PLAN_NOT_PRESENT);

    /**
     * Undefined
     */
    public static final int _ADDRESS_PLAN_UNDEFINED =  1;

    /**
     * Undefined
     */
    public static final AddressPlan ADDRESS_PLAN_UNDEFINED = new AddressPlan(_ADDRESS_PLAN_UNDEFINED);

    /**
     * IP
     */
    public static final int _ADDRESS_PLAN_IP =  2;

    /**
     * IP
     */
    public static final AddressPlan ADDRESS_PLAN_IP = new AddressPlan(_ADDRESS_PLAN_IP);

    /**
     * Multicast
     */
    public static final int _ADDRESS_PLAN_MULTICAST =  3;

    /**
     * Multicast
     */
    public static final AddressPlan ADDRESS_PLAN_MULTICAST = new AddressPlan(_ADDRESS_PLAN_MULTICAST);

    /**
     * Unicast
     */
    public static final int _ADDRESS_PLAN_UNICAST =  4;

    /**
     * Unicast
     */
    public static final AddressPlan ADDRESS_PLAN_UNICAST = new AddressPlan(_ADDRESS_PLAN_UNICAST);

    /**
     * ITU-T Recommendation E.164 
     */
    public static final int _ADDRESS_PLAN_E164 =  5;

    /**
     * ITU-T Recommendation E.164 
     */
    public static final AddressPlan ADDRESS_PLAN_E164 = new AddressPlan(_ADDRESS_PLAN_E164);

    /**
     * AESA
     */
    public static final int _ADDRESS_PLAN_AESA =  6;

    /**
     * AESA
     */
    public static final AddressPlan ADDRESS_PLAN_AESA = new AddressPlan(_ADDRESS_PLAN_AESA);

    /**
     * URL
     */
    public static final int _ADDRESS_PLAN_URL =  7;

    /**
     * URL
     */
    public static final AddressPlan ADDRESS_PLAN_URL = new AddressPlan(_ADDRESS_PLAN_URL);

    /**
     * NSAP
     */
    public static final int _ADDRESS_PLAN_NSAP =  8;

    /**
     * NSAP
     */
    public static final AddressPlan ADDRESS_PLAN_NSAP = new AddressPlan(_ADDRESS_PLAN_NSAP);

    /**
     * SMTP
     */
    public static final int _ADDRESS_PLAN_SMTP =  9;

    /**
     * SMTP
     */
    public static final AddressPlan ADDRESS_PLAN_SMTP = new AddressPlan(_ADDRESS_PLAN_SMTP);

    /**
     * Microsoft Mail
     */
    public static final int _ADDRESS_PLAN_MSMAIL =  10;

    /**
     * Microsoft Mail
     */
    public static final AddressPlan ADDRESS_PLAN_MSMAIL = new AddressPlan(_ADDRESS_PLAN_MSMAIL);

    /**
     * ITU-T Recommendation X.400
     */
    public static final int _ADDRESS_PLAN_X400 =  11;

    /**
     * ITU-T Recommendation X.400
     */
    public static final AddressPlan ADDRESS_PLAN_X400 = new AddressPlan(_ADDRESS_PLAN_X400);

    /**
     * Any address plan is deemed to match (This is only used for TpAddressRange)
     */
    public static final int _ADDRESS_PLAN_ANY =  13;

    /**
     * Any address plan is deemed to match (This is only used for TpAddressRange)
     */
    public static final AddressPlan ADDRESS_PLAN_ANY = new AddressPlan(_ADDRESS_PLAN_ANY);

    /**
     * Any valid address string allowed in RFC 3261 'SIP: Session Initiation Protocol'
     */
    public static final int _ADDRESS_PLAN_SIP =  12;

    /**
     * Any valid address string allowed in RFC 3261 'SIP: Session Initiation Protocol'
     */
    public static final AddressPlan ADDRESS_PLAN_SIP = new AddressPlan(_ADDRESS_PLAN_SIP);

    /**
     * Reserved for National Specific use
     */
    public static final int _ADDRESS_PLAN_NATIONAL =  14;

    /**
     * Reserved for National Specific use
     */
    public static final AddressPlan ADDRESS_PLAN_NATIONAL = new AddressPlan(_ADDRESS_PLAN_NATIONAL);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved AddressPlan object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the AddressPlan object
     */
    public String getValueText() {
        switch (_value) {
            case _ADDRESS_PLAN_NOT_PRESENT:
                return "ADDRESS_PLAN_NOT_PRESENT";
            case _ADDRESS_PLAN_UNDEFINED:
                return "ADDRESS_PLAN_UNDEFINED";
            case _ADDRESS_PLAN_IP:
                return "ADDRESS_PLAN_IP";
            case _ADDRESS_PLAN_MULTICAST:
                return "ADDRESS_PLAN_MULTICAST";
            case _ADDRESS_PLAN_UNICAST:
                return "ADDRESS_PLAN_UNICAST";
            case _ADDRESS_PLAN_E164:
                return "ADDRESS_PLAN_E164";
            case _ADDRESS_PLAN_AESA:
                return "ADDRESS_PLAN_AESA";
            case _ADDRESS_PLAN_URL:
                return "ADDRESS_PLAN_URL";
            case _ADDRESS_PLAN_NSAP:
                return "ADDRESS_PLAN_NSAP";
            case _ADDRESS_PLAN_SMTP:
                return "ADDRESS_PLAN_SMTP";
            case _ADDRESS_PLAN_MSMAIL:
                return "ADDRESS_PLAN_MSMAIL";
            case _ADDRESS_PLAN_X400:
                return "ADDRESS_PLAN_X400";
            case _ADDRESS_PLAN_ANY:
                return "ADDRESS_PLAN_ANY";
            case _ADDRESS_PLAN_SIP:
                return "ADDRESS_PLAN_SIP";
            case _ADDRESS_PLAN_NATIONAL:
                return "ADDRESS_PLAN_NATIONAL";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 14
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static AddressPlan getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof AddressPlan)) {
            return false;
        }
        AddressPlan addressPlan = (AddressPlan) o; 
        if(!(this.getValue() == addressPlan.getValue())) {
            return false;
        }
        if (this.hashCode() != addressPlan.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // AddressPlan

