//Source file: AddressPresentation.java
//Date: June 2006
//Common Data Types for 3GPP TS 29.198-02 V6.5.0

package org.csapi.jr.se;

/**
 * Defines whether an address can be presented to an end user.
 *
 */
public final class AddressPresentation implements java.io.Serializable {

    private int _value;
    private static int _size = 4;
    private static AddressPresentation[] _array = new AddressPresentation[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private AddressPresentation(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Undefined
     */
    public static final int _ADDRESS_PRESENTATION_UNDEFINED =  0;

    /**
     * Undefined
     */
    public static final AddressPresentation ADDRESS_PRESENTATION_UNDEFINED = new AddressPresentation(_ADDRESS_PRESENTATION_UNDEFINED);

    /**
     * Presentation Allowed
     */
    public static final int _ADDRESS_PRESENTATION_ALLOWED =  1;

    /**
     * Presentation Allowed
     */
    public static final AddressPresentation ADDRESS_PRESENTATION_ALLOWED = new AddressPresentation(_ADDRESS_PRESENTATION_ALLOWED);

    /**
     * Presentation Restricted
     */
    public static final int _ADDRESS_PRESENTATION_RESTRICTED =  2;

    /**
     * Presentation Restricted
     */
    public static final AddressPresentation ADDRESS_PRESENTATION_RESTRICTED = new AddressPresentation(_ADDRESS_PRESENTATION_RESTRICTED);

    /**
     * Address not available for presentation
     */
    public static final int _ADDRESS_PRESENTATION_ADDRESS_NOT_AVAILABLE =  3;

    /**
     * Address not available for presentation
     */
    public static final AddressPresentation ADDRESS_PRESENTATION_ADDRESS_NOT_AVAILABLE = new AddressPresentation(_ADDRESS_PRESENTATION_ADDRESS_NOT_AVAILABLE);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved AddressPresentation object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the AddressPresentation object
     */
    public String getValueText() {
        switch (_value) {
            case _ADDRESS_PRESENTATION_UNDEFINED:
                return "ADDRESS_PRESENTATION_UNDEFINED";
            case _ADDRESS_PRESENTATION_ALLOWED:
                return "ADDRESS_PRESENTATION_ALLOWED";
            case _ADDRESS_PRESENTATION_RESTRICTED:
                return "ADDRESS_PRESENTATION_RESTRICTED";
            case _ADDRESS_PRESENTATION_ADDRESS_NOT_AVAILABLE:
                return "ADDRESS_PRESENTATION_ADDRESS_NOT_AVAILABLE";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 3
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static AddressPresentation getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof AddressPresentation)) {
            return false;
        }
        AddressPresentation addressPresentation = (AddressPresentation) o; 
        if(!(this.getValue() == addressPresentation.getValue())) {
            return false;
        }
        if (this.hashCode() != addressPresentation.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // AddressPresentation

