//Source file: AddressRange.java
//Date: June 2006
//Common Data Types for 3GPP TS 29.198-02 V6.5.0

package org.csapi.jr.se;

/**
 * Defines the Sequence of Data Elements that specify a range of addresses.
The AddrString defines the actual address information and the structure of the string depends on the Plan. 
An overview of the AddrString formats can be found at the description of the TpAddress data-type.
The difference with TpAddress is that there is no Presentation and Screening elements, the AddrString can contain wildcards and Plan may contain P_ADDRESS_PLAN_ANY.
If P_ADDRESS_PLAN_ANY is set then the TpAddressRange will be deemed by the gateway to match any TpAddress. If a specific Plan is set (including P_ADDRESS_PLAN_NOT_PRESENT) then the address plan of the range must be identical to the plan contained in an address for the two to match.
Two wildcards are allowed: * which matches zero or more characters and ? which matches exactly one character. For E.164 addresses, * which matches zero or more characters and ? are allowed at the beginning or end.
Some examples for E.164 addresses:
'123'	matches specific number;
'123*'	matches all numbers starting with 123 (including 123 itself);
'123??*'	matches all numbers starting with 123 and at least 5 digits long;
'123???'	matches all numbers starting with 123 and exactly 6 digits long;
'*'	matches any address
The following address ranges are illegal:
'1?3' 
'1*3' 
'?123*'
''
Legal occurrences of the '*' and '?' characters in AddrString should be escaped by a '\' character. To specify a '\' character '\' must be used.
For e-mail style addresses, the wildcards are allowed at the beginning of the AddrString:
'*@parlay.org'	matches all email addresses in the parlay.org domain.
For SIP addresses, a range of  wildcard options may be supported:
'sip:*@parlay.org'	matches all SIP addresses at parlay.org:5060.
'sip:*.domain1.com'	Matches all SIP addresses in the domain domain1.com
'sip:user*@*' 			Matches all users starting with the string 'user'
'sip:user*@*:5060'  	Matches all users starting with the string 'user' using port 5060
'sip:*'						Matches all SIP addresses
'sip:*@*'					Matches all SIP addresses
'sip:user*@*:5060' 		Matches all users starting with the string 'user' using port 5060
In addition for SIP addresses, the absence of an explicit port number at the end of a SIP address, shall be considered to indicate an implicit wildcard for any port number. 
'sip:user1@parlay.org' may be considered equivalent to 'sip:user1@parlay.org:*'
 * 
 */
public final class AddressRange implements java.io.Serializable {

    private org.csapi.jr.se.AddressPlan plan;
    private String addrString;
    private String name;
    private String subAddressString;

    /**
     * Creates a new AddressRange instance.
     */
    public AddressRange () {}

    /**
     * Creates a new AddressRange instance.
     * @param _plan   
     * @param _addrString   
     * @param _name   
     * @param _subAddressString   
     */
    public AddressRange (org.csapi.jr.se.AddressPlan _plan, String _addrString, String _name, String _subAddressString) {

        this.plan = _plan;
        this.addrString = _addrString;
        this.name = _name;
        this.subAddressString = _subAddressString;
    }

    /**
     * This method returns a plan.
     * 
     * @return a org.csapi.jr.se.AddressPlan value
     */
    public org.csapi.jr.se.AddressPlan getPlan() {
        return plan;
    }

    /**
     * This method returns a addrString.
     * 
     * @return a String value
     */
    public String getAddrString() {
        return addrString;
    }

    /**
     * This method returns a name.
     * 
     * @return a String value
     */
    public String getName() {
        return name;
    }

    /**
     * This method returns a subAddressString.
     * 
     * @return a String value
     */
    public String getSubAddressString() {
        return subAddressString;
    }


    /**
     * This method sets a plan.
     */ 
    public void setPlan(org.csapi.jr.se.AddressPlan plan) {
        this.plan = plan;
    }

    /**
     * This method sets a addrString.
     */ 
    public void setAddrString(String addrString) {
        this.addrString = addrString;
    }

    /**
     * This method sets a name.
     */ 
    public void setName(String name) {
        this.name = name;
    }

    /**
     * This method sets a subAddressString.
     */ 
    public void setSubAddressString(String subAddressString) {
        this.subAddressString = subAddressString;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof AddressRange)) {
            return false;
        } 
        AddressRange addressRange = (AddressRange) o;
        if ((this.plan != null) && (addressRange.plan != null)) {
            if(!(this.plan.equals(addressRange.plan))) {
                return false;
            }
        }
        if ((this.addrString != null) && (addressRange.addrString != null)) {
            if(!(this.addrString.equals(addressRange.addrString)))  {
                return false;
            }
        }
        if ((this.name != null) && (addressRange.name != null)) {
            if(!(this.name.equals(addressRange.name)))  {
                return false;
            }
        }
        if ((this.subAddressString != null) && (addressRange.subAddressString != null)) {
            if(!(this.subAddressString.equals(addressRange.subAddressString)))  {
                return false;
            }
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // AddressRange

