//Source file: AddressScreening.java
//Date: June 2006
//Common Data Types for 3GPP TS 29.198-02 V6.5.0

package org.csapi.jr.se;

/**
 * Defines whether an address can be presented to an end user.
 *
 */
public final class AddressScreening implements java.io.Serializable {

    private int _value;
    private static int _size = 5;
    private static AddressScreening[] _array = new AddressScreening[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private AddressScreening(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Undefined
     */
    public static final int _ADDRESS_SCREENING_UNDEFINED =  0;

    /**
     * Undefined
     */
    public static final AddressScreening ADDRESS_SCREENING_UNDEFINED = new AddressScreening(_ADDRESS_SCREENING_UNDEFINED);

    /**
     * user provided address verified and passed
     */
    public static final int _ADDRESS_SCREENING_USER_VERIFIED_PASSED =  1;

    /**
     * user provided address verified and passed
     */
    public static final AddressScreening ADDRESS_SCREENING_USER_VERIFIED_PASSED = new AddressScreening(_ADDRESS_SCREENING_USER_VERIFIED_PASSED);

    /**
     * user provided address not verified
     */
    public static final int _ADDRESS_SCREENING_USER_NOT_VERIFIED =  2;

    /**
     * user provided address not verified
     */
    public static final AddressScreening ADDRESS_SCREENING_USER_NOT_VERIFIED = new AddressScreening(_ADDRESS_SCREENING_USER_NOT_VERIFIED);

    /**
     * user provided address verified and failed
     */
    public static final int _ADDRESS_SCREENING_USER_VERIFIED_FAILED =  3;

    /**
     * user provided address verified and failed
     */
    public static final AddressScreening ADDRESS_SCREENING_USER_VERIFIED_FAILED = new AddressScreening(_ADDRESS_SCREENING_USER_VERIFIED_FAILED);

    /**
     * Network provided address (Note that even though the application may provide the address to the gateway, from the end-user point of view it is still regarded as a network provided address)
     */
    public static final int _ADDRESS_SCREENING_NETWORK =  4;

    /**
     * Network provided address (Note that even though the application may provide the address to the gateway, from the end-user point of view it is still regarded as a network provided address)
     */
    public static final AddressScreening ADDRESS_SCREENING_NETWORK = new AddressScreening(_ADDRESS_SCREENING_NETWORK);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved AddressScreening object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the AddressScreening object
     */
    public String getValueText() {
        switch (_value) {
            case _ADDRESS_SCREENING_UNDEFINED:
                return "ADDRESS_SCREENING_UNDEFINED";
            case _ADDRESS_SCREENING_USER_VERIFIED_PASSED:
                return "ADDRESS_SCREENING_USER_VERIFIED_PASSED";
            case _ADDRESS_SCREENING_USER_NOT_VERIFIED:
                return "ADDRESS_SCREENING_USER_NOT_VERIFIED";
            case _ADDRESS_SCREENING_USER_VERIFIED_FAILED:
                return "ADDRESS_SCREENING_USER_VERIFIED_FAILED";
            case _ADDRESS_SCREENING_NETWORK:
                return "ADDRESS_SCREENING_NETWORK";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 4
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static AddressScreening getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof AddressScreening)) {
            return false;
        }
        AddressScreening addressScreening = (AddressScreening) o; 
        if(!(this.getValue() == addressScreening.getValue())) {
            return false;
        }
        if (this.hashCode() != addressScreening.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // AddressScreening

