//Source file: AttributeTagInfo.java
//Date: June 2006
//Common Data Types for 3GPP TS 29.198-02 V6.5.0

package org.csapi.jr.se;

/**
 * TpAttributeTagInfo is an enumerated type used as a discriminator for the TpAttributeValue structure.
 *
 */
public final class AttributeTagInfo implements java.io.Serializable {

    private int _value;
    private static int _size = 3;
    private static AttributeTagInfo[] _array = new AttributeTagInfo[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private AttributeTagInfo(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Simple type
     */
    public static final int _SIMPLE_TYPE =  0;

    /**
     * Simple type
     */
    public static final AttributeTagInfo SIMPLE_TYPE = new AttributeTagInfo(_SIMPLE_TYPE);

    /**
     * Structured type
     */
    public static final int _STRUCTURED_TYPE =  1;

    /**
     * Structured type
     */
    public static final AttributeTagInfo STRUCTURED_TYPE = new AttributeTagInfo(_STRUCTURED_TYPE);

    /**
     * XML type
     */
    public static final int _XML_TYPE =  2;

    /**
     * XML type
     */
    public static final AttributeTagInfo XML_TYPE = new AttributeTagInfo(_XML_TYPE);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved AttributeTagInfo object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the AttributeTagInfo object
     */
    public String getValueText() {
        switch (_value) {
            case _SIMPLE_TYPE:
                return "SIMPLE_TYPE";
            case _STRUCTURED_TYPE:
                return "STRUCTURED_TYPE";
            case _XML_TYPE:
                return "XML_TYPE";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 2
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static AttributeTagInfo getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof AttributeTagInfo)) {
            return false;
        }
        AttributeTagInfo attributeTagInfo = (AttributeTagInfo) o; 
        if(!(this.getValue() == attributeTagInfo.getValue())) {
            return false;
        }
        if (this.hashCode() != attributeTagInfo.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // AttributeTagInfo

