//Source file: AttributeValue.java
//Date: June 2006
//Common Data Types for 3GPP TS 29.198-02 V6.5.0

package org.csapi.jr.se;

/**
 * This is a tagged choice of data elements to hold attribute values of different complexity.
 *
 */
public final class AttributeValue implements java.io.Serializable {

    private AttributeTagInfo _discriminator = null;
    private java.lang.Object _object;

    /**
     * Creates a new AttributeValue.
     * Tagged choice of data elements always have empty constructors
     */ 
    public AttributeValue() {}

    /**
     * This method returns the discriminator.
     * 
     * @return a AttributeTagInfo value 
     * @exception InvalidUnionAccessorException if an error occurs 
     */ 
    public AttributeTagInfo getDiscriminator() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator == null) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return _discriminator;
    }

    /**
     * This method returns a SimpleValue
     * 
     * @return  a org.csapi.jr.se.SimpleAttributeValue value
     * @exception InvalidUnionAccessorException if an error occurs 
     */
    public org.csapi.jr.se.SimpleAttributeValue getSimpleValue() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator != AttributeTagInfo.SIMPLE_TYPE) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return ((org.csapi.jr.se.SimpleAttributeValue) _object);
    }

    /**
     * This method sets a SimpleValue
     * 
     * @param value a org.csapi.jr.se.SimpleAttributeValue value
     */
    public void setSimpleValue(org.csapi.jr.se.SimpleAttributeValue value) {
        _discriminator = AttributeTagInfo.SIMPLE_TYPE;
        _object = value;
    }

    /**
     * This method returns a StructuredValue
     * 
     * @return  a org.csapi.jr.se.StructuredAttributeValue value
     * @exception InvalidUnionAccessorException if an error occurs 
     */
    public org.csapi.jr.se.StructuredAttributeValue getStructuredValue() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator != AttributeTagInfo.STRUCTURED_TYPE) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return ((org.csapi.jr.se.StructuredAttributeValue) _object);
    }

    /**
     * This method sets a StructuredValue
     * 
     * @param value a org.csapi.jr.se.StructuredAttributeValue value
     */
    public void setStructuredValue(org.csapi.jr.se.StructuredAttributeValue value) {
        _discriminator = AttributeTagInfo.STRUCTURED_TYPE;
        _object = value;
    }

    /**
     * This method returns a XMLValue
     * 
     * @return  a java.lang.String value
     * @exception InvalidUnionAccessorException if an error occurs 
     */
    public java.lang.String getXMLValue() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator != AttributeTagInfo.XML_TYPE) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return (((java.lang.String) _object));
    }

    /**
     * This method sets a XMLValue
     * 
     * @param value a java.lang.String value
     */
    public void setXMLValue(java.lang.String value) {
        _discriminator = AttributeTagInfo.XML_TYPE;
        _object = value;
    }


    /**
     * This method will receive the discriminator as a parameter and will set _object to null
     * 
     * @param discriminator a AttributeTagInfo value 
     */ 
    public void setUndefined(AttributeTagInfo discriminator) {
        _discriminator = discriminator;
        _object = null;
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) {
            return false;
        }
        if(!(o instanceof AttributeValue)) {
            return false;
        } else {
            AttributeValue attributeValue= (AttributeValue)o;
            if(!(this._object.equals(attributeValue._object))){
                return false;
            } else {
                if(!(this._discriminator.equals(attributeValue._discriminator))){
                    return false;
                }
            }
            if (this.hashCode() != o.hashCode()) {
                return false;
            }
            return true;
        }
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // AttributeValue

