//Source file: CAIElements.java
//Date: June 2006
//Common Data Types for 3GPP TS 29.198-02 V6.5.0

package org.csapi.jr.se;

/**
 * Defines the Sequence of Data Elements that specify the Charging Advice Information elements according to TS 122 024.
 * 
 */
public final class CAIElements implements java.io.Serializable {

    private int unitsPerInterval;
    private int secondsPerTimeInterval;
    private int scalingFactor;
    private int unitIncrement;
    private int unitsPerDataInterval;
    private int segmentsPerDataInterval;
    private int initialSecsPerTimeInterval;

    /**
     * Creates a new CAIElements instance.
     */
    public CAIElements () {}

    /**
     * Creates a new CAIElements instance.
     * @param _unitsPerInterval   Units per interval
     * @param _secondsPerTimeInterval   Seconds per time interval
     * @param _scalingFactor   Scaling factor
     * @param _unitIncrement   Unit increment
     * @param _unitsPerDataInterval   Units per data interval
     * @param _segmentsPerDataInterval   Segments per data interval
     * @param _initialSecsPerTimeInterval   Initial secs per time interval
     */
    public CAIElements (int _unitsPerInterval, int _secondsPerTimeInterval, int _scalingFactor, int _unitIncrement, int _unitsPerDataInterval, int _segmentsPerDataInterval, int _initialSecsPerTimeInterval) {

        this.unitsPerInterval = _unitsPerInterval;
        this.secondsPerTimeInterval = _secondsPerTimeInterval;
        this.scalingFactor = _scalingFactor;
        this.unitIncrement = _unitIncrement;
        this.unitsPerDataInterval = _unitsPerDataInterval;
        this.segmentsPerDataInterval = _segmentsPerDataInterval;
        this.initialSecsPerTimeInterval = _initialSecsPerTimeInterval;
    }

    /**
     * This method returns a unitsPerInterval.
     * 
     * @return a int value
     */
    public int getUnitsPerInterval() {
        return unitsPerInterval;
    }

    /**
     * This method returns a secondsPerTimeInterval.
     * 
     * @return a int value
     */
    public int getSecondsPerTimeInterval() {
        return secondsPerTimeInterval;
    }

    /**
     * This method returns a scalingFactor.
     * 
     * @return a int value
     */
    public int getScalingFactor() {
        return scalingFactor;
    }

    /**
     * This method returns a unitIncrement.
     * 
     * @return a int value
     */
    public int getUnitIncrement() {
        return unitIncrement;
    }

    /**
     * This method returns a unitsPerDataInterval.
     * 
     * @return a int value
     */
    public int getUnitsPerDataInterval() {
        return unitsPerDataInterval;
    }

    /**
     * This method returns a segmentsPerDataInterval.
     * 
     * @return a int value
     */
    public int getSegmentsPerDataInterval() {
        return segmentsPerDataInterval;
    }

    /**
     * This method returns a initialSecsPerTimeInterval.
     * 
     * @return a int value
     */
    public int getInitialSecsPerTimeInterval() {
        return initialSecsPerTimeInterval;
    }


    /**
     * This method sets a unitsPerInterval.
     */ 
    public void setUnitsPerInterval(int unitsPerInterval) {
        this.unitsPerInterval = unitsPerInterval;
    }

    /**
     * This method sets a secondsPerTimeInterval.
     */ 
    public void setSecondsPerTimeInterval(int secondsPerTimeInterval) {
        this.secondsPerTimeInterval = secondsPerTimeInterval;
    }

    /**
     * This method sets a scalingFactor.
     */ 
    public void setScalingFactor(int scalingFactor) {
        this.scalingFactor = scalingFactor;
    }

    /**
     * This method sets a unitIncrement.
     */ 
    public void setUnitIncrement(int unitIncrement) {
        this.unitIncrement = unitIncrement;
    }

    /**
     * This method sets a unitsPerDataInterval.
     */ 
    public void setUnitsPerDataInterval(int unitsPerDataInterval) {
        this.unitsPerDataInterval = unitsPerDataInterval;
    }

    /**
     * This method sets a segmentsPerDataInterval.
     */ 
    public void setSegmentsPerDataInterval(int segmentsPerDataInterval) {
        this.segmentsPerDataInterval = segmentsPerDataInterval;
    }

    /**
     * This method sets a initialSecsPerTimeInterval.
     */ 
    public void setInitialSecsPerTimeInterval(int initialSecsPerTimeInterval) {
        this.initialSecsPerTimeInterval = initialSecsPerTimeInterval;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof CAIElements)) {
            return false;
        } 
        CAIElements cAIElements = (CAIElements) o;
        if(!(this.initialSecsPerTimeInterval == cAIElements.initialSecsPerTimeInterval)) {
            return false;
        }
        if(!(this.secondsPerTimeInterval == cAIElements.secondsPerTimeInterval)) {
            return false;
        }
        if(!(this.segmentsPerDataInterval == cAIElements.segmentsPerDataInterval)) {
            return false;
        }
        if(!(this.scalingFactor == cAIElements.scalingFactor)) {
            return false;
        }
        if(!(this.unitIncrement == cAIElements.unitIncrement)) {
            return false;
        }
        if(!(this.unitsPerDataInterval == cAIElements.unitsPerDataInterval)) {
            return false;
        }
        if(!(this.unitsPerInterval == cAIElements.unitsPerInterval)) {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // CAIElements

