//Source file: CallAoCOrderCategory.java
//Date: June 2006
//Common Data Types for 3GPP TS 29.198-02 V6.5.0

package org.csapi.jr.se;

/**
 * 
 *
 */
public final class CallAoCOrderCategory implements java.io.Serializable {

    private int _value;
    private static int _size = 3;
    private static CallAoCOrderCategory[] _array = new CallAoCOrderCategory[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private CallAoCOrderCategory(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Set of GSM Charge Advice Information elements according to TS 122 024
     */
    public static final int _CHARGE_ADVICE_INFO =  0;

    /**
     * Set of GSM Charge Advice Information elements according to TS 122 024
     */
    public static final CallAoCOrderCategory CHARGE_ADVICE_INFO = new CallAoCOrderCategory(_CHARGE_ADVICE_INFO);

    /**
     * Charge per time
     */
    public static final int _CHARGE_PER_TIME =  1;

    /**
     * Charge per time
     */
    public static final CallAoCOrderCategory CHARGE_PER_TIME = new CallAoCOrderCategory(_CHARGE_PER_TIME);

    /**
     * Operator specific charge plan specification, for example charging table name / charging table entry
     */
    public static final int _CHARGE_NETWORK =  2;

    /**
     * Operator specific charge plan specification, for example charging table name / charging table entry
     */
    public static final CallAoCOrderCategory CHARGE_NETWORK = new CallAoCOrderCategory(_CHARGE_NETWORK);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved CallAoCOrderCategory object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the CallAoCOrderCategory object
     */
    public String getValueText() {
        switch (_value) {
            case _CHARGE_ADVICE_INFO:
                return "CHARGE_ADVICE_INFO";
            case _CHARGE_PER_TIME:
                return "CHARGE_PER_TIME";
            case _CHARGE_NETWORK:
                return "CHARGE_NETWORK";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 2
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static CallAoCOrderCategory getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof CallAoCOrderCategory)) {
            return false;
        }
        CallAoCOrderCategory callAoCOrderCategory = (CallAoCOrderCategory) o; 
        if(!(this.getValue() == callAoCOrderCategory.getValue())) {
            return false;
        }
        if (this.hashCode() != callAoCOrderCategory.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // CallAoCOrderCategory

