//Source file: ChargeAdviceInfo.java
//Date: June 2006
//Common Data Types for 3GPP TS 29.198-02 V6.5.0

package org.csapi.jr.se;

/**
 * Defines the Sequence of Data Elements that specify the two sets of Advice of Charge parameters. The first set defines the current tariff. The second set may be used in case of a tariff switch in the network.
 * 
 */
public final class ChargeAdviceInfo implements java.io.Serializable {

    private org.csapi.jr.se.CAIElements currentCAI;
    private org.csapi.jr.se.CAIElements nextCAI;

    /**
     * Creates a new ChargeAdviceInfo instance.
     */
    public ChargeAdviceInfo () {}

    /**
     * Creates a new ChargeAdviceInfo instance.
     * @param _currentCAI   Current tariff
     * @param _nextCAI   Next tariff after tariff switch
     */
    public ChargeAdviceInfo (org.csapi.jr.se.CAIElements _currentCAI, org.csapi.jr.se.CAIElements _nextCAI) {

        this.currentCAI = _currentCAI;
        this.nextCAI = _nextCAI;
    }

    /**
     * This method returns a currentCAI.
     * 
     * @return a org.csapi.jr.se.CAIElements value
     */
    public org.csapi.jr.se.CAIElements getCurrentCAI() {
        return currentCAI;
    }

    /**
     * This method returns a nextCAI.
     * 
     * @return a org.csapi.jr.se.CAIElements value
     */
    public org.csapi.jr.se.CAIElements getNextCAI() {
        return nextCAI;
    }


    /**
     * This method sets a currentCAI.
     */ 
    public void setCurrentCAI(org.csapi.jr.se.CAIElements currentCAI) {
        this.currentCAI = currentCAI;
    }

    /**
     * This method sets a nextCAI.
     */ 
    public void setNextCAI(org.csapi.jr.se.CAIElements nextCAI) {
        this.nextCAI = nextCAI;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof ChargeAdviceInfo)) {
            return false;
        } 
        ChargeAdviceInfo chargeAdviceInfo = (ChargeAdviceInfo) o;
        if ((this.nextCAI != null) && (chargeAdviceInfo.nextCAI != null)) {
            if(!(this.nextCAI.equals(chargeAdviceInfo.nextCAI))) {
                return false;
            }
        }
        if ((this.currentCAI != null) && (chargeAdviceInfo.currentCAI != null)) {
            if(!(this.currentCAI.equals(chargeAdviceInfo.currentCAI))) {
                return false;
            }
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // ChargeAdviceInfo

