//Source file: ChargePerTime.java
//Date: June 2006
//Common Data Types for 3GPP TS 29.198-02 V6.5.0

package org.csapi.jr.se;

/**
 * Defines the Sequence of Data Elements that specify the time based charging information.
 * 
 */
public final class ChargePerTime implements java.io.Serializable {

    private int initialCharge;
    private int currentChargePerMinute;
    private int nextChargePerMinute;

    /**
     * Creates a new ChargePerTime instance.
     */
    public ChargePerTime () {}

    /**
     * Creates a new ChargePerTime instance.
     * @param _initialCharge   Initial charge amount (in currency units * 0.0001)
     * @param _currentChargePerMinute   Current tariff (in currency units * 0.0001)
     * @param _nextChargePerMinute   Next tariff (in currency units * 0.0001) after tariff switch. Only used in setAdviceOfCharge()
     */
    public ChargePerTime (int _initialCharge, int _currentChargePerMinute, int _nextChargePerMinute) {

        this.initialCharge = _initialCharge;
        this.currentChargePerMinute = _currentChargePerMinute;
        this.nextChargePerMinute = _nextChargePerMinute;
    }

    /**
     * This method returns a initialCharge.
     * 
     * @return a int value
     */
    public int getInitialCharge() {
        return initialCharge;
    }

    /**
     * This method returns a currentChargePerMinute.
     * 
     * @return a int value
     */
    public int getCurrentChargePerMinute() {
        return currentChargePerMinute;
    }

    /**
     * This method returns a nextChargePerMinute.
     * 
     * @return a int value
     */
    public int getNextChargePerMinute() {
        return nextChargePerMinute;
    }


    /**
     * This method sets a initialCharge.
     */ 
    public void setInitialCharge(int initialCharge) {
        this.initialCharge = initialCharge;
    }

    /**
     * This method sets a currentChargePerMinute.
     */ 
    public void setCurrentChargePerMinute(int currentChargePerMinute) {
        this.currentChargePerMinute = currentChargePerMinute;
    }

    /**
     * This method sets a nextChargePerMinute.
     */ 
    public void setNextChargePerMinute(int nextChargePerMinute) {
        this.nextChargePerMinute = nextChargePerMinute;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof ChargePerTime)) {
            return false;
        } 
        ChargePerTime chargePerTime = (ChargePerTime) o;
        if(!(this.currentChargePerMinute == chargePerTime.currentChargePerMinute)) {
            return false;
        }
        if(!(this.initialCharge == chargePerTime.initialCharge)) {
            return false;
        }
        if(!(this.nextChargePerMinute == chargePerTime.nextChargePerMinute)) {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // ChargePerTime

