//Source file: DataSessionQosClass.java
//Date: June 2006
//Common Data Types for 3GPP TS 29.198-02 V6.5.0

package org.csapi.jr.se;

/**
 * Defines the Quality of Service (QoS) classes.  This could be for a data session or multi media call session, for example.
	    Note: Because of commonality across multiple interface specifications, this data type is promoted from Data Session Control Data Types to Common Data Types. For backward compatibility reasons, the naming of the data type remains unmodified, and hence continues to refer to Data Session Control.
 *
 */
public final class DataSessionQosClass implements java.io.Serializable {

    private int _value;
    private static int _size = 4;
    private static DataSessionQosClass[] _array = new DataSessionQosClass[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private DataSessionQosClass(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Specifies the Conversational QoS class, as specified in 3G TS 23.107.
     */
    public static final int _DATA_SESSION_QOS_CLASS_CONVERSATIONAL =  0;

    /**
     * Specifies the Conversational QoS class, as specified in 3G TS 23.107.
     */
    public static final DataSessionQosClass DATA_SESSION_QOS_CLASS_CONVERSATIONAL = new DataSessionQosClass(_DATA_SESSION_QOS_CLASS_CONVERSATIONAL);

    /**
     * Specifies the Streaming QoS class, as specified in 3G TS 23.107.
     */
    public static final int _DATA_SESSION_QOS_CLASS_STREAMING =  1;

    /**
     * Specifies the Streaming QoS class, as specified in 3G TS 23.107.
     */
    public static final DataSessionQosClass DATA_SESSION_QOS_CLASS_STREAMING = new DataSessionQosClass(_DATA_SESSION_QOS_CLASS_STREAMING);

    /**
     * Specifies the Interactive QoS class, as specified in 3G TS 23.107.
     */
    public static final int _DATA_SESSION_QOS_CLASS_INTERACTIVE =  2;

    /**
     * Specifies the Interactive QoS class, as specified in 3G TS 23.107.
     */
    public static final DataSessionQosClass DATA_SESSION_QOS_CLASS_INTERACTIVE = new DataSessionQosClass(_DATA_SESSION_QOS_CLASS_INTERACTIVE);

    /**
     * Specifies the Background QoS class, as specified in 3G TS 23.107.
     */
    public static final int _DATA_SESSION_QOS_CLASS_BACKGROUND =  3;

    /**
     * Specifies the Background QoS class, as specified in 3G TS 23.107.
     */
    public static final DataSessionQosClass DATA_SESSION_QOS_CLASS_BACKGROUND = new DataSessionQosClass(_DATA_SESSION_QOS_CLASS_BACKGROUND);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved DataSessionQosClass object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the DataSessionQosClass object
     */
    public String getValueText() {
        switch (_value) {
            case _DATA_SESSION_QOS_CLASS_CONVERSATIONAL:
                return "DATA_SESSION_QOS_CLASS_CONVERSATIONAL";
            case _DATA_SESSION_QOS_CLASS_STREAMING:
                return "DATA_SESSION_QOS_CLASS_STREAMING";
            case _DATA_SESSION_QOS_CLASS_INTERACTIVE:
                return "DATA_SESSION_QOS_CLASS_INTERACTIVE";
            case _DATA_SESSION_QOS_CLASS_BACKGROUND:
                return "DATA_SESSION_QOS_CLASS_BACKGROUND";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 3
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static DataSessionQosClass getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof DataSessionQosClass)) {
            return false;
        }
        DataSessionQosClass dataSessionQosClass = (DataSessionQosClass) o; 
        if(!(this.getValue() == dataSessionQosClass.getValue())) {
            return false;
        }
        if (this.hashCode() != dataSessionQosClass.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // DataSessionQosClass

