//Source file: SimpleAttributeTypeInfo.java
//Date: June 2006
//Common Data Types for 3GPP TS 29.198-02 V6.5.0

package org.csapi.jr.se;

/**
 * TpSimpleAttributeTypeInfo is an enumerated type used as a discriminator for the TpSimpleAttributeValue structure.
 *
 */
public final class SimpleAttributeTypeInfo implements java.io.Serializable {

    private int _value;
    private static int _size = 14;
    private static SimpleAttributeTypeInfo[] _array = new SimpleAttributeTypeInfo[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private SimpleAttributeTypeInfo(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Attribute type is type TpBoolean.
     */
    public static final int _BOOLEAN =  0;

    /**
     * Attribute type is type TpBoolean.
     */
    public static final SimpleAttributeTypeInfo BOOLEAN = new SimpleAttributeTypeInfo(_BOOLEAN);

    /**
     * Attribute type is type TpOctet.
     */
    public static final int _OCTET =  1;

    /**
     * Attribute type is type TpOctet.
     */
    public static final SimpleAttributeTypeInfo OCTET = new SimpleAttributeTypeInfo(_OCTET);

    /**
     * Attribute type is type TpChar.
     */
    public static final int _CHAR =  2;

    /**
     * Attribute type is type TpChar.
     */
    public static final SimpleAttributeTypeInfo CHAR = new SimpleAttributeTypeInfo(_CHAR);

    /**
     * Attribute type is type TpWChar.
     */
    public static final int _WCHAR =  3;

    /**
     * Attribute type is type TpWChar.
     */
    public static final SimpleAttributeTypeInfo WCHAR = new SimpleAttributeTypeInfo(_WCHAR);

    /**
     * Attribute type is type TpString.
     */
    public static final int _STRING =  4;

    /**
     * Attribute type is type TpString.
     */
    public static final SimpleAttributeTypeInfo STRING = new SimpleAttributeTypeInfo(_STRING);

    /**
     * Attribute type is type TpWString.
     */
    public static final int _WSTRING =  5;

    /**
     * Attribute type is type TpWString.
     */
    public static final SimpleAttributeTypeInfo WSTRING = new SimpleAttributeTypeInfo(_WSTRING);

    /**
     * Attribute type is type TpInt16.
     */
    public static final int _INT16 =  6;

    /**
     * Attribute type is type TpInt16.
     */
    public static final SimpleAttributeTypeInfo INT16 = new SimpleAttributeTypeInfo(_INT16);

    /**
     * Attribute type is type TpUnsignedInt16.
     */
    public static final int _UNSIGNED_INT16 =  7;

    /**
     * Attribute type is type TpUnsignedInt16.
     */
    public static final SimpleAttributeTypeInfo UNSIGNED_INT16 = new SimpleAttributeTypeInfo(_UNSIGNED_INT16);

    /**
     * Attribute type is type TpInt32.
     */
    public static final int _INT32 =  8;

    /**
     * Attribute type is type TpInt32.
     */
    public static final SimpleAttributeTypeInfo INT32 = new SimpleAttributeTypeInfo(_INT32);

    /**
     * Attribute type is type TpUnsignedInt32.
     */
    public static final int _UNSIGNED_INT32 =  9;

    /**
     * Attribute type is type TpUnsignedInt32.
     */
    public static final SimpleAttributeTypeInfo UNSIGNED_INT32 = new SimpleAttributeTypeInfo(_UNSIGNED_INT32);

    /**
     * Attribute type is type TpInt64
     */
    public static final int _INT64 =  10;

    /**
     * Attribute type is type TpInt64
     */
    public static final SimpleAttributeTypeInfo INT64 = new SimpleAttributeTypeInfo(_INT64);

    /**
     * Attribute type is type TpUnsignedInt64.
     */
    public static final int _UNSIGNED_INT64 =  11;

    /**
     * Attribute type is type TpUnsignedInt64.
     */
    public static final SimpleAttributeTypeInfo UNSIGNED_INT64 = new SimpleAttributeTypeInfo(_UNSIGNED_INT64);

    /**
     * Attribute type is type TpFloat.
     */
    public static final int _FLOAT =  12;

    /**
     * Attribute type is type TpFloat.
     */
    public static final SimpleAttributeTypeInfo FLOAT = new SimpleAttributeTypeInfo(_FLOAT);

    /**
     * Attribute type is type TpDouble.
     */
    public static final int _DOUBLE =  13;

    /**
     * Attribute type is type TpDouble.
     */
    public static final SimpleAttributeTypeInfo DOUBLE = new SimpleAttributeTypeInfo(_DOUBLE);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved SimpleAttributeTypeInfo object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the SimpleAttributeTypeInfo object
     */
    public String getValueText() {
        switch (_value) {
            case _BOOLEAN:
                return "BOOLEAN";
            case _OCTET:
                return "OCTET";
            case _CHAR:
                return "CHAR";
            case _WCHAR:
                return "WCHAR";
            case _STRING:
                return "STRING";
            case _WSTRING:
                return "WSTRING";
            case _INT16:
                return "INT16";
            case _UNSIGNED_INT16:
                return "UNSIGNED_INT16";
            case _INT32:
                return "INT32";
            case _UNSIGNED_INT32:
                return "UNSIGNED_INT32";
            case _INT64:
                return "INT64";
            case _UNSIGNED_INT64:
                return "UNSIGNED_INT64";
            case _FLOAT:
                return "FLOAT";
            case _DOUBLE:
                return "DOUBLE";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 13
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static SimpleAttributeTypeInfo getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof SimpleAttributeTypeInfo)) {
            return false;
        }
        SimpleAttributeTypeInfo simpleAttributeTypeInfo = (SimpleAttributeTypeInfo) o; 
        if(!(this.getValue() == simpleAttributeTypeInfo.getValue())) {
            return false;
        }
        if (this.hashCode() != simpleAttributeTypeInfo.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // SimpleAttributeTypeInfo

