//Source file: SimpleAttributeValue.java
//Date: June 2006
//Common Data Types for 3GPP TS 29.198-02 V6.5.0

package org.csapi.jr.se;

/**
 * This is a tagged choice of data elements to hold attribute values of different complexity.
 *
 */
public final class SimpleAttributeValue implements java.io.Serializable {

    private SimpleAttributeTypeInfo _discriminator = null;
    private java.lang.Object _object;

    /**
     * Creates a new SimpleAttributeValue.
     * Tagged choice of data elements always have empty constructors
     */ 
    public SimpleAttributeValue() {}

    /**
     * This method returns the discriminator.
     * 
     * @return a SimpleAttributeTypeInfo value 
     * @exception InvalidUnionAccessorException if an error occurs 
     */ 
    public SimpleAttributeTypeInfo getDiscriminator() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator == null) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return _discriminator;
    }

    /**
     * This method returns a BooleanValue
     * 
     * @return  a boolean value
     * @exception InvalidUnionAccessorException if an error occurs 
     */
    public boolean getBooleanValue() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator != SimpleAttributeTypeInfo.BOOLEAN) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return (((java.lang.Boolean) _object).booleanValue());
    }

    /**
     * This method sets a BooleanValue
     * 
     * @param value a boolean value
     */
    public void setBooleanValue(boolean value) {
        _discriminator = SimpleAttributeTypeInfo.BOOLEAN;
        _object = new java.lang.Boolean(value);
    }

    /**
     * This method returns a OctetValue
     * 
     * @return  a byte value
     * @exception InvalidUnionAccessorException if an error occurs 
     */
    public byte getOctetValue() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator != SimpleAttributeTypeInfo.OCTET) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return (((java.lang.Byte) _object).byteValue());
    }

    /**
     * This method sets a OctetValue
     * 
     * @param value a byte value
     */
    public void setOctetValue(byte value) {
        _discriminator = SimpleAttributeTypeInfo.OCTET;
        _object = new java.lang.Byte(value);
    }

    /**
     * This method returns a CharValue
     * 
     * @return  a char value
     * @exception InvalidUnionAccessorException if an error occurs 
     */
    public char getCharValue() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator != SimpleAttributeTypeInfo.CHAR) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return (((java.lang.Character) _object).charValue());
    }

    /**
     * This method sets a CharValue
     * 
     * @param value a char value
     */
    public void setCharValue(char value) {
        _discriminator = SimpleAttributeTypeInfo.CHAR;
        _object = new java.lang.Character(value);
    }

    /**
     * This method returns a WCharValue
     * 
     * @return  a char value
     * @exception InvalidUnionAccessorException if an error occurs 
     */
    public char getWCharValue() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator != SimpleAttributeTypeInfo.WCHAR) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return (((java.lang.Character) _object).charValue());
    }

    /**
     * This method sets a WCharValue
     * 
     * @param value a char value
     */
    public void setWCharValue(char value) {
        _discriminator = SimpleAttributeTypeInfo.WCHAR;
        _object = new java.lang.Character(value);
    }

    /**
     * This method returns a StringValue
     * 
     * @return  a java.lang.String value
     * @exception InvalidUnionAccessorException if an error occurs 
     */
    public java.lang.String getStringValue() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator != SimpleAttributeTypeInfo.STRING) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return (((java.lang.String) _object));
    }

    /**
     * This method sets a StringValue
     * 
     * @param value a java.lang.String value
     */
    public void setStringValue(java.lang.String value) {
        _discriminator = SimpleAttributeTypeInfo.STRING;
        _object = value;
    }

    /**
     * This method returns a WStringValue
     * 
     * @return  a java.lang.String value
     * @exception InvalidUnionAccessorException if an error occurs 
     */
    public java.lang.String getWStringValue() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator != SimpleAttributeTypeInfo.WSTRING) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return (((java.lang.String) _object));
    }

    /**
     * This method sets a WStringValue
     * 
     * @param value a java.lang.String value
     */
    public void setWStringValue(java.lang.String value) {
        _discriminator = SimpleAttributeTypeInfo.WSTRING;
        _object = value;
    }

    /**
     * This method returns a Int16Value
     * 
     * @return  a short value
     * @exception InvalidUnionAccessorException if an error occurs 
     */
    public short getInt16Value() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator != SimpleAttributeTypeInfo.INT16) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return (((java.lang.Short) _object).shortValue());
    }

    /**
     * This method sets a Int16Value
     * 
     * @param value a short value
     */
    public void setInt16Value(short value) {
        _discriminator = SimpleAttributeTypeInfo.INT16;
        _object = new java.lang.Short(value);
    }

    /**
     * This method returns a UnsignedInt16Value
     * 
     * @return  a short value
     * @exception InvalidUnionAccessorException if an error occurs 
     */
    public short getUnsignedInt16Value() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator != SimpleAttributeTypeInfo.UNSIGNED_INT16) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return (((java.lang.Short) _object).shortValue());
    }

    /**
     * This method sets a UnsignedInt16Value
     * 
     * @param value a short value
     */
    public void setUnsignedInt16Value(short value) {
        _discriminator = SimpleAttributeTypeInfo.UNSIGNED_INT16;
        _object = new java.lang.Short(value);
    }

    /**
     * This method returns a Int32Value
     * 
     * @return  a int value
     * @exception InvalidUnionAccessorException if an error occurs 
     */
    public int getInt32Value() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator != SimpleAttributeTypeInfo.INT32) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return (((java.lang.Integer) _object).intValue());
    }

    /**
     * This method sets a Int32Value
     * 
     * @param value a int value
     */
    public void setInt32Value(int value) {
        _discriminator = SimpleAttributeTypeInfo.INT32;
        _object = new java.lang.Integer(value);
    }

    /**
     * This method returns a UnsignedInt32Value
     * 
     * @return  a int value
     * @exception InvalidUnionAccessorException if an error occurs 
     */
    public int getUnsignedInt32Value() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator != SimpleAttributeTypeInfo.UNSIGNED_INT32) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return (((java.lang.Integer) _object).intValue());
    }

    /**
     * This method sets a UnsignedInt32Value
     * 
     * @param value a int value
     */
    public void setUnsignedInt32Value(int value) {
        _discriminator = SimpleAttributeTypeInfo.UNSIGNED_INT32;
        _object = new java.lang.Integer(value);
    }

    /**
     * This method returns a Int64Value
     * 
     * @return  a long value
     * @exception InvalidUnionAccessorException if an error occurs 
     */
    public long getInt64Value() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator != SimpleAttributeTypeInfo.INT64) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return (((java.lang.Long) _object).longValue());
    }

    /**
     * This method sets a Int64Value
     * 
     * @param value a long value
     */
    public void setInt64Value(long value) {
        _discriminator = SimpleAttributeTypeInfo.INT64;
        _object = new java.lang.Long(value);
    }

    /**
     * This method returns a UnsignedInt64Value
     * 
     * @return  a long value
     * @exception InvalidUnionAccessorException if an error occurs 
     */
    public long getUnsignedInt64Value() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator != SimpleAttributeTypeInfo.UNSIGNED_INT64) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return (((java.lang.Long) _object).longValue());
    }

    /**
     * This method sets a UnsignedInt64Value
     * 
     * @param value a long value
     */
    public void setUnsignedInt64Value(long value) {
        _discriminator = SimpleAttributeTypeInfo.UNSIGNED_INT64;
        _object = new java.lang.Long(value);
    }

    /**
     * This method returns a FloatValue
     * 
     * @return  a float value
     * @exception InvalidUnionAccessorException if an error occurs 
     */
    public float getFloatValue() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator != SimpleAttributeTypeInfo.FLOAT) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return (((java.lang.Float) _object).floatValue());
    }

    /**
     * This method sets a FloatValue
     * 
     * @param value a float value
     */
    public void setFloatValue(float value) {
        _discriminator = SimpleAttributeTypeInfo.FLOAT;
        _object = new java.lang.Float(value);
    }

    /**
     * This method returns a DoubleValue
     * 
     * @return  a double value
     * @exception InvalidUnionAccessorException if an error occurs 
     */
    public double getDoubleValue() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator != SimpleAttributeTypeInfo.DOUBLE) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return (((java.lang.Double) _object).doubleValue());
    }

    /**
     * This method sets a DoubleValue
     * 
     * @param value a double value
     */
    public void setDoubleValue(double value) {
        _discriminator = SimpleAttributeTypeInfo.DOUBLE;
        _object = new java.lang.Double(value);
    }


    /**
     * This method will receive the discriminator as a parameter and will set _object to null
     * 
     * @param discriminator a SimpleAttributeTypeInfo value 
     */ 
    public void setUndefined(SimpleAttributeTypeInfo discriminator) {
        _discriminator = discriminator;
        _object = null;
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) {
            return false;
        }
        if(!(o instanceof SimpleAttributeValue)) {
            return false;
        } else {
            SimpleAttributeValue simpleAttributeValue= (SimpleAttributeValue)o;
            if(!(this._object.equals(simpleAttributeValue._object))){
                return false;
            } else {
                if(!(this._discriminator.equals(simpleAttributeValue._discriminator))){
                    return false;
                }
            }
            if (this.hashCode() != o.hashCode()) {
                return false;
            }
            return true;
        }
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // SimpleAttributeValue

