//Source file: StructuredAttributeValue.java
//Date: June 2006
//Common Data Types for 3GPP TS 29.198-02 V6.5.0

package org.csapi.jr.se;

/**
 * This is a Sequence of Data Elements containing the structured attribute type tag and the value to be interpreted using that type.
 * 
 */
public final class StructuredAttributeValue implements java.io.Serializable {

    private String type;
    private Object value;

    /**
     * Creates a new StructuredAttributeValue instance.
     */
    public StructuredAttributeValue () {}

    /**
     * Creates a new StructuredAttributeValue instance.
     * @param _type   
     * @param _value   
     */
    public StructuredAttributeValue (String _type, Object _value) {

        this.type = _type;
        this.value = _value;
    }

    /**
     * This method returns a type.
     * 
     * @return a String value
     */
    public String getType() {
        return type;
    }

    /**
     * This method returns a value.
     * 
     * @return a Object value
     */
    public Object getValue() {
        return value;
    }


    /**
     * This method sets a type.
     */ 
    public void setType(String type) {
        this.type = type;
    }

    /**
     * This method sets a value.
     */ 
    public void setValue(Object value) {
        this.value = value;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof StructuredAttributeValue)) {
            return false;
        } 
        StructuredAttributeValue structuredAttributeValue = (StructuredAttributeValue) o;
        if(!(this.type == structuredAttributeValue.type))  {
            return false;
        }
        if(!(this.value == structuredAttributeValue.value)) {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // StructuredAttributeValue

